@@ -7,10 +7,10 @@ app = Typer()
 
 
 @app.command()
-def init(template_url: str):
+def init(template_url: str = "git@github.com:0xsirsaif/enabled-project-template.git"):
     """
     Create a new project from a template.
-    template_url: The url of the template to use.
+    template_url: The url of the template to use. the default is the 0xsirsaif/enabled-project-template.
     """
     print(f"Creating new project from {template_url}...")
     subprocess.run(["cookiecutter", template_url])
